/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/**
 * Interface that represents a callback to be passed to requestAnimationFrame
 */

#include "domstubs.idl"

[scriptable, function, uuid(e8d887f0-2ed7-406f-9f1d-edeb2c54c0a2)]
interface nsIFrameRequestCallback : nsISupports
{
  /**
   * The timestamp is the time to be used for the animation sample.
   */
  void sample(in DOMTimeStamp timeStamp);
};
