/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:set ts=2 sw=2 sts=2 et cindent: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIProtocolProxyService.idl"

/**
 * An extension of nsIProtocolProxyService
 */
[scriptable, uuid(bb52e571-4a0e-4363-83d0-52034910dd14)]
interface nsIProtocolProxyService2 : nsIProtocolProxyService
{
  /**
   * Call this method to cause the PAC file (if any is configured) to be
   * reloaded.  The PAC file is loaded asynchronously.
   */
  void reloadPAC();

  /**
   * This exists so Java(tm) can migrate to an asynchronous interface.
   * Do not use this unless you are the plugin interface, and even then you
   * ought to feel horribly guilty because you will create main thread jank.
   *
   * No documentation - it is deprecated!
   **/
  nsIProxyInfo deprecatedBlockingResolve(in nsIURI aURI, in unsigned long aFlags);

    /**
     * This method is identical to asyncResolve() except it may execute the
     * callback function immediately (i.e from the stack of asyncResolve2()) if
     * it is immediately ready to run. The nsICancelable return value will be
     * null in that case.
     */
  nsICancelable asyncResolve2(in nsIURI aURI, in unsigned long aFlags,
                              in nsIProtocolProxyCallback aCallback);
};
